Pattern

Enum Pattern 

pub enum Pattern {
    Pulse,
    Chase,
    Sparkle,
    KnightRider,
}
Pattern type to be passed to execute_pattern.

Variants



Pulse

All LEDs gently pulse.



Chase

Endless scrolling of bands of color (for all solid colors), and endless scrolling of a rainbow for Color::Rainbow.



Sparkle

Random LEDs across the strip will suddenly brighten and fade slowly to off.



KnightRider

Inspired by the iconic lighting in the car K.I.T.T. from the 80s TV show Knight Rider.